@@ -51,6 +51,7 @@
 
 #include <pthread.h>
 
+#undef _NPTH_NO_RWLOCK
 #ifdef __ANDROID__
 #include <android/api-level.h>
 #if __ANDROID_API__ < 9
@@ -215,6 +216,7 @@ int npth_mutex_timedlock(npth_mutex_t *mutex, const struct timespec *abstime);
 
 #define npth_mutex_unlock pthread_mutex_unlock
 
+#if defined(__USE_UNIX98) || defined(__USE_XOPEN2K)
 #ifdef _NPTH_NO_RWLOCK
 
 typedef int npth_rwlockattr_t;
@@ -284,6 +286,7 @@ int npth_rwlock_timedwrlock (npth_rwlock_t *rwlock,
 #define npth_rwlock_unlock  pthread_rwlock_unlock
 
 #endif /* !_NPTH_NO_RWLOCK */
+#endif
 
 
 typedef pthread_cond_t npth_cond_t;
@@ -345,6 +348,11 @@ ssize_t npth_write(int fd, const void *buf, size_t nbytes);
 int npth_recvmsg (int fd, struct msghdr *msg, int flags);
 int npth_sendmsg (int fd, const struct msghdr *msg, int flags);
 
+struct pollfd;
+int npth_poll (struct pollfd *fds, unsigned long nfds, int timeout);
+int npth_ppoll (struct pollfd *fds, unsigned long nfds,
+                const struct timespec *timeout, const sigset_t *sigmask);
+
 /* For anything not covered here, you can enter/leave manually at your
    own risk.  */
 void npth_unprotect (void);
